@@ -176,6 +176,11 @@ public class OsmTileLoader implements TileLoader {
         return getClass().getSimpleName();
     }
 
+    @Override
+    public boolean hasOutstandingTasks() {
+        return jobDispatcher.getTaskCount() > jobDispatcher.getCompletedTaskCount();
+    }
+
     @Override
     public void cancelOutstandingTasks() {
         jobDispatcher.getQueue().clear();
