@@ -8,6 +8,7 @@ import java.util.Map;
 
 import org.openstreetmap.gui.jmapviewer.JMapViewer;
 import org.openstreetmap.gui.jmapviewer.Tile;
+import org.openstreetmap.gui.jmapviewer.TileRange;
 import org.openstreetmap.gui.jmapviewer.TileXY;
 
 /**
@@ -96,21 +97,24 @@ public interface TileSource extends Attributed {
     double getDistance(double la1, double lo1, double la2, double lo2);
 
     /**
+     * Transforms longitude and latitude to pixel space (as if all tiles at specified zoom level where joined).
      * @param lon longitude
      * @param lat latitude
      * @param zoom zoom level
-     * @return transforms longitude and latitude to pixel space (as if all tiles at specified zoom level where joined)
+     * @return the pixel coordinates
      */
     Point latLonToXY(double lat, double lon, int zoom);
 
     /**
+     * Transforms longitude and latitude to pixel space (as if all tiles at specified zoom level where joined).
      * @param point point
      * @param zoom zoom level
-     * @return transforms longitude and latitude to pixel space (as if all tiles at specified zoom level where joined)
+     * @return the pixel coordinates
      */
     Point latLonToXY(ICoordinate point, int zoom);
 
     /**
+     * Transforms a point in pixel space to longitude/latitude (WGS84).
      * @param point point
      * @param zoom zoom level
      * @return WGS84 Coordinates of given point
@@ -118,7 +122,7 @@ public interface TileSource extends Attributed {
     ICoordinate xyToLatLon(Point point, int zoom);
 
     /**
-     *
+     * Transforms a point in pixel space to longitude/latitude (WGS84).
      * @param x X coordinate
      * @param y Y coordinate
      * @param zoom zoom level
@@ -127,6 +131,7 @@ public interface TileSource extends Attributed {
     ICoordinate xyToLatLon(int x, int y, int zoom);
 
     /**
+     * Transforms longitude and latitude to tile indices.
      * @param lon longitude
      * @param lat latitude
      * @param zoom zoom level
@@ -135,7 +140,7 @@ public interface TileSource extends Attributed {
     TileXY latLonToTileXY(double lat, double lon, int zoom);
 
     /**
-     *
+     * Transforms longitude and latitude to tile indices.
      * @param point point
      * @param zoom zoom level
      * @return x and y tile indices
@@ -143,51 +148,55 @@ public interface TileSource extends Attributed {
     TileXY latLonToTileXY(ICoordinate point, int zoom);
 
     /**
-     * @param xy X/Y coordinates
+     * Transforms tile indices to longitude and latitude.
+     * @param xy X/Y tile indices
      * @param zoom zoom level
      * @return WGS84 coordinates of given tile
      */
     ICoordinate tileXYToLatLon(TileXY xy, int zoom);
 
     /**
-     *
+     * Determines to longitude and latitude of a tile.
+     * (Refers to the tile origin - upper left tile corner)
      * @param tile Tile
      * @return WGS84 coordinates of given tile
      */
     ICoordinate tileXYToLatLon(Tile tile);
 
     /**
-     *
-     * @param x X coordinate
-     * @param y Y coordinate
+     * Transforms tile indices to longitude and latitude.
+     * @param x x tile index
+     * @param y y tile index
      * @param zoom zoom level
      * @return WGS84 coordinates of given tile
      */
     ICoordinate tileXYToLatLon(int x, int y, int zoom);
 
     /**
+     * Get maximum x index of tile for specified zoom level.
      * @param zoom zoom level
-     * @return maximum X index of tile for specified zoom level
+     * @return maximum x index of tile for specified zoom level
      */
     int getTileXMax(int zoom);
 
     /**
-     *
+     * Get minimum x index of tile for specified zoom level.
      * @param zoom zoom level
-     * @return minimum X index of tile for specified zoom level
+     * @return minimum x index of tile for specified zoom level
      */
     int getTileXMin(int zoom);
 
     /**
-     *
+     * Get maximum y index of tile for specified zoom level.
      * @param zoom zoom level
-     * @return maximum Y index of tile for specified zoom level
+     * @return maximum y index of tile for specified zoom level
      */
     int getTileYMax(int zoom);
 
     /**
+     * Get minimum y index of tile for specified zoom level
      * @param zoom zoom level
-     * @return minimum Y index of tile for specified zoom level
+     * @return minimum y index of tile for specified zoom level
      */
     int getTileYMin(int zoom);
 
@@ -209,4 +218,62 @@ public interface TileSource extends Attributed {
      * @return tile metadata
      */
     Map<String, String> getMetadata(Map<String, List<String>> headers);
+
+    /**
+     * Convert tile indices (x/y/zoom) into projected coordinates of the tile origin.
+     * @param x x tile index
+     * @param y z tile index
+     * @param zoom zoom level
+     * @return projected coordinates of the tile origin
+     */
+    IProjected tileXYtoProjected(int x, int y, int zoom);
+
+    /**
+     * Convert projected coordinates to tile indices.
+     * @param p projected coordinates
+     * @param zoom zoom level
+     * @return corresponding tile index x/y (floating point, truncate to integer
+     * for tile index)
+     */
+    TileXY projectedToTileXY(IProjected p, int zoom);
+
+    /**
+     * Check if one tile is inside another tile.
+     * @param inner the tile that is suspected to be inside the other tile
+     * @param outer the tile that might contain the first tile
+     * @return true if first tile is inside second tile (or both are identical),
+     * false otherwise
+     */
+    boolean isInside(Tile inner, Tile outer);
+
+    /**
+     * Returns a range of tiles, that cover a given tile, which is
+     * usually at a different zoom level.
+     *
+     * In standard tile layout, 4 tiles cover a tile one zoom lower, 16 tiles
+     * cover a tile 2 zoom levels below etc.
+     * If the zoom level of the covering tiles is greater or equal, a single
+     * tile suffices.
+     *
+     * @param tile the tile to cover
+     * @param newZoom zoom level of the covering tiles
+     * @return TileRange of all covering tiles at zoom <code>newZoom</code>
+     */
+    TileRange getCoveringTileRange(Tile tile, int newZoom);
+
+    /**
+     * Get coordinate reference system for this tile source.
+     *
+     * E.g. "EPSG:3857" for Google-Mercator.
+     * @return code for the coordinate reference system in use
+     */
+    String getServerCRS();
+
+    /**
+     * Determines if this imagery supports "/dirty" mode (tile re-rendering).
+     * @return <code>true</code> if it supports "/dirty" mode (tile re-rendering)
+     */
+    default boolean isModTileFeatures() {
+        return false;
+    }
 }
